<template>
  <div class="tree-menu">
    <SearchBar @search="handleSearch" />
    <el-tree
      ref="treeRef"
      :data="filteredData"
      :props="defaultProps"
      :filter-node-method="filterNode"
      default-expand-all
      @node-click="handleNodeClick"
    >
      <template #default="{ node, data }">
        <span class="custom-tree-node">
          <el-icon v-if="data.icon"><component :is="data.icon" /></el-icon>
          <span>{{ node.label }}</span>
        </span>
      </template>
    </el-tree>
  </div>
</template>

<script setup lang="ts">
import { ref, watch } from 'vue'
import { useRouter } from 'vue-router'
import SearchBar from './SearchBar.vue'
import { Document, FolderOpened } from '@element-plus/icons-vue'

const router = useRouter()
const treeRef = ref()

interface TreeNode {
  label: string
  path?: string
  icon?: string
  children?: TreeNode[]
}

const treeData = ref<TreeNode[]>([
  {
    label: '模型管理',
    icon: 'FolderOpened',
    children: [
      {
        label: '机构模型',
        path: '/mechanism',
        icon: 'Document'
      },
      {
        label: '运动学模型',
        path: '/kinematic',
        icon: 'Document'
      }
    ]
  },
  {
    label: '可视化仿真',
    icon: 'FolderOpened',
    children: [
      {
        label: '仿真配置',
        path: '/simulation-config',
        icon: 'Document'
      },
      {
        label: '仿真结果',
        path: '/simulation-result',
        icon: 'Document'
      }
    ]
  },
  {
    label: '系统管理',
    icon: 'FolderOpened',
    children: [
      {
        label: '用户管理',
        path: '/system/user',
        icon: 'Document'
      },
      {
        label: '权限设置',
        path: '/system/permission',
        icon: 'Document'
      }
    ]
  }
])

const defaultProps = {
  children: 'children',
  label: 'label'
}

const filteredData = ref(treeData.value)

const filterNode = (value: string, data: TreeNode) => {
  if (!value) return true
  return data.label.toLowerCase().includes(value.toLowerCase())
}

const handleSearch = (searchText: string) => {
  treeRef.value?.filter(searchText)
}

const handleNodeClick = (data: TreeNode) => {
  if (data.path) {
    router.push(data.path)
  }
}
</script>

<style lang="less" scoped>
.tree-menu {
  height: 100%;
  background-color: #fff;
  
  :deep(.el-tree) {
    padding: 10px;
  }
  
  .custom-tree-node {
    display: flex;
    align-items: center;
    gap: 8px;
  }
}
</style> 